@@ -745,12 +745,21 @@ cdrecord_stderr_line (NautilusBurnProcess   *process,
                                                          _("Error while writing to disc.  Try a lower speed."),
                                                          NAUTILUS_BURN_RECORDER_RESULT_ERROR);
                 }
-        } else if (strstr (line, "DMA speed too slow") != NULL) {
+	} else if (strstr (line, "Sense Key:") != NULL) {
+		if (strstr (line, "Medium Error") != NULL) {
+			nautilus_burn_process_set_error (process,
+							 _("Error while writing to disc.  The disc is damaged or unreadable."),
+							 NAUTILUS_BURN_RECORDER_RESULT_ERROR);
+		}
+        } else if ((strstr (line, "DMA speed too slow") != NULL)
+        	   || (strstr (line, "wodim: A write error occured.") != NULL)
+        	   || (strstr (line, "wodim: A write error occurred.") != NULL)) {
                 nautilus_burn_process_set_error (process,
                                                  _("The system is too slow to write the CD at this speed. Try a lower speed."),
                                                  NAUTILUS_BURN_RECORDER_RESULT_ERROR);
         }
 
+
         return TRUE;
 }
 
