@@ -50,6 +50,7 @@ static void     ncb_selection_dialog_finalize   (GObject                 *object
 struct NcbSelectionDialogPrivate
 {
         GladeXML                *xml;
+        GtkWidget               *write_button;
         NcbSelection            *selection;
         guint                    update_selection_idle_id;
 };
@@ -171,6 +172,8 @@ update_source (NcbSelectionDialog *dialog)
                 gtk_window_set_title (GTK_WINDOW (dialog), _("Copy Disc"));
                 widget = glade_xml_get_widget (dialog->priv->xml, "target_label");
                 gtk_label_set_text_with_mnemonic (GTK_LABEL (widget), _("Copy disc _to:"));
+                /* Translators: This is "Copy" as in the action to copy the disc onto another one */
+                gtk_button_set_label (GTK_BUTTON (dialog->priv->write_button), _("_Copy"));
         } else {
                 gtk_window_set_title (GTK_WINDOW (dialog), _("Write to Disc"));
         }
@@ -273,6 +276,13 @@ label_entry_changed (GtkEditable        *editable,
         g_free (text);
 }
 
+static void
+label_entry_activated (GtkEntry           *editable,
+		       NcbSelectionDialog *dialog)
+{
+	gtk_dialog_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
+}
+
 static void
 ncb_selection_dialog_set_drive (NcbSelectionDialog *dialog,
                                 NautilusBurnDrive  *drive)
@@ -603,7 +613,6 @@ static void
 ncb_selection_dialog_init (NcbSelectionDialog *dialog)
 {
         GtkWidget *vbox;
-        GtkWidget *button;
         GtkWidget *entry;
 
         dialog->priv = NCB_SELECTION_DIALOG_GET_PRIVATE (dialog);
@@ -634,7 +643,8 @@ ncb_selection_dialog_init (NcbSelectionDialog *dialog)
 
         gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_HELP, GTK_RESPONSE_HELP);
         gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
-        button = gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Write"), GTK_RESPONSE_OK);
+        dialog->priv->write_button = gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Write"), GTK_RESPONSE_OK);
+        gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
 
         init_dialog (dialog);
 
@@ -646,6 +656,7 @@ ncb_selection_dialog_init (NcbSelectionDialog *dialog)
         entry = glade_xml_get_widget (dialog->priv->xml, "cdname_entry");
         g_signal_connect (entry, "insert_text", G_CALLBACK (label_entry_insert_text), dialog);
         g_signal_connect (entry, "changed", G_CALLBACK (label_entry_changed), dialog);
+        g_signal_connect (entry, "activate", G_CALLBACK (label_entry_activated), dialog);
 }
 
 static void
